@@ -6,7 +6,6 @@ from xrspatial.utils import ngjit
 from typing import Union, Optional
 
 import warnings
-warnings.simplefilter('default')
 
 
 NONE = -1
@@ -238,18 +237,18 @@ def a_star_search(surface: xr.DataArray,
     Calculate distance from a starting point to a
     goal through a surface graph. Starting location
     and goal location should be within the graph.
-    
+
     A* is a modification of Dijkstra’s Algorithm
     that is optimized for a single destination.
     Dijkstra’s Algorithm can find paths to all
     locations; A* finds paths to one location,
     or the closest of several locations. It prioritizes
     paths that seem to be leading closer to a goal.
-    
+
     The output is an equal sized Xarray.DataArray
     with NaNs for non-path pixels, and the value
     of the path pixels being the current cost up to that point.
-    
+
     Parameters:
     ----------
     surface: xarray.DataArray
@@ -266,10 +265,12 @@ def a_star_search(surface: xr.DataArray,
         name of the y coordinate in input surface raster
     connectivity: int (default = 8)
     snap_start: bool (default = False)
-        snap the start location to the nearest valid value before beginning pathfinding
+        snap the start location to the nearest valid value before
+    beginning pathfinding
     snap_goal: bool (default = False)
-        snap the goal location to the nearest valid value before beginning pathfinding
-        
+        snap the goal location to the nearest valid value before
+    beginning pathfinding
+
     Returns:
     ----------
     path_agg: Xarray.DataArray
@@ -279,15 +280,15 @@ def a_star_search(surface: xr.DataArray,
     Notes:
     ----------
     Algorithm References:
-        - https://www.redblobgames.com/pathfinding/a-star/implementation.html
-        - https://medium.com/@nicholas.w.swift/easy-a-star-pathfinding-7e6689c7f7b2
+    - https://www.redblobgames.com/pathfinding/a-star/implementation.html
+    - https://medium.com/@nicholas.w.swift/easy-a-star-pathfinding-7e6689c7f7b2
 
     Examples:
     ----------
     Imports
     >>> import numpy as np
     >>> import xarray as xr
-    >>> from xrspatial import pathfinding
+    >>> from xrspatial import pathfinding as pf
 
     Create Surface Data Array
     >>> agg = xr.DataArray(np.array([[0, 0, 0, 0, 0],
@@ -303,7 +304,7 @@ def a_star_search(surface: xr.DataArray,
     >>> agg["lat"] = _lat
 
     Create Path Data Array
-    >>> print(pathfinding.a_star_search(agg, (0,0), (4,4), x = 'lon', y = 'lat'))
+    >>> print(pf.a_star_search(agg, (0,0), (4,4), x = 'lon', y = 'lat'))
     <xarray.DataArray (lat: 5, lon: 5)>
     array([[0.        , nan, nan, nan, nan],
            [nan, 1.41421356, nan, nan, nan],
@@ -348,7 +349,9 @@ def a_star_search(surface: xr.DataArray,
         start_py, start_px = _find_nearest_pixel(start_py, start_px,
                                                  surface.data, barriers)
     if _is_not_crossable(surface.data[start_py, start_px], barriers):
-        warnings.warn('Start at a non crossable pixel', Warning)
+        with warnings.catch_warnings():
+            warnings.simplefilter("default")
+            warnings.warn('Start at a non crossable pixel', Warning)
 
     goal_py, goal_px = _find_pixel_id(goal[0], goal[1], x_coords, y_coords)
     if snap_goal:
@@ -356,10 +359,14 @@ def a_star_search(surface: xr.DataArray,
         goal_py, goal_px = _find_nearest_pixel(goal_py, goal_px,
                                                surface.data, barriers)
     if _is_not_crossable(surface.data[goal_py, goal_px], barriers):
-        warnings.warn('End at a non crossable pixel', Warning)
+        with warnings.catch_warnings():
+            warnings.simplefilter("default")
+            warnings.warn('End at a non crossable pixel', Warning)
 
     if start_py == NONE or goal_py == NONE:
-        warnings.warn('No valid pixels in input surface', Warning)
+        with warnings.catch_warnings():
+            warnings.simplefilter("default")
+            warnings.warn('No valid pixels in input surface', Warning)
 
     # 2d output image that stores the path
     path_img = np.zeros_like(surface, dtype=np.float64)
