@@ -61,12 +61,13 @@ def render_tiles(full_extent, levels, load_data_func,
     results = dict()
     for level in levels:
         print('calculating statistics for level {}'.format(level))
-        span = calculate_zoom_level_stats(full_extent,
-                                          level,
-                                          load_data_func,
-                                          rasterize_func,
-                                          color_ranging_strategy =
-                                          color_ranging_strategy)
+        span = calculate_zoom_level_stats(
+            full_extent,
+            level,
+            load_data_func,
+            rasterize_func,
+            color_ranging_strategy=color_ranging_strategy,
+        )
 
         super_tiles = list(gen_super_tiles(full_extent, level, span))
         print(f'rendering {len(super_tiles)} supertiles for zoom level {level}'
